@@ -9,6 +9,7 @@ FILES=" Form_MainWindow
 	Form_NewProject
 	Form_SymbolManager
 	Form_Wizard
+	Form_StyleDialog
         ./ConfigurationPages/Form_IOSRouterPage
         ./ConfigurationPages/Form_CloudPage
         ./ConfigurationPages/Form_ETHSWPage
@@ -17,11 +18,13 @@ FILES=" Form_MainWindow
         ./ConfigurationPages/Form_ATMSWPage
         ./ConfigurationPages/Form_ATMBRPage
         ./ConfigurationPages/Form_FWPage
+        ./ConfigurationPages/Form_SIMHOSTPage
         ./ConfigurationPages/Form_DecorativeNodePage
         ./ConfigurationPages/Form_PreferencesGeneral
         ./ConfigurationPages/Form_PreferencesDynamips
         ./ConfigurationPages/Form_PreferencesCapture
         ./ConfigurationPages/Form_PreferencesPemu
+        ./ConfigurationPages/Form_PreferencesSimhost
 "
 
 # Update files...
